/*
  Smartglove fo cyclists: https://www.instructables.com/member/Matlek/
  This code is made to record gestures (copy/paste from the monitor);
  It is a modified version of "IMU_Capture" : https://github.com/arduino/ArduinoTensorFlowLiteTutorials/blob/master/GestureToEmoji/ArduinoSketches/IMU_Capture/IMU_Capture.ino
*/

#include <Arduino_LSM9DS1.h>

const float gyroscopeThreshold = 300;
const int numSamples = 64;
int samplesRead = numSamples;
int nbGesture = 0; //added

void setup() {
  Serial.begin(9600);
  while (!Serial);

  if (!IMU.begin()) {
    Serial.println("Failed to initialize IMU!");
    while (1);
  }

  pinMode(22, OUTPUT);
  pinMode(23, OUTPUT);
  pinMode(24, OUTPUT);
  digitalWrite(22, HIGH);
  digitalWrite(23, HIGH);
  digitalWrite(24, HIGH);

  // print the header
  Serial.println("aX,aY,aZ,gX,gY,gZ");
}

void loop() {
  float aX, aY, aZ, gX, gY, gZ;

  if (nbGesture <= 20) {
    digitalWrite(22, LOW);
  }
  if (nbGesture >= 21 && nbGesture <= 40) {
    digitalWrite(22, HIGH);
    digitalWrite(23, LOW);
  }
  if (nbGesture >= 41 && nbGesture <= 60) {
    digitalWrite(23, HIGH);
    digitalWrite(24, LOW);
  }
  if (nbGesture >= 61 && nbGesture <= 80) {
    digitalWrite(24, HIGH);
    digitalWrite(22, LOW);
  }
  if (nbGesture >= 81 && nbGesture <= 101) {
    digitalWrite(22, HIGH);
    digitalWrite(23, LOW);
  }
  if (nbGesture >= 101 && nbGesture <= 120) {
    digitalWrite(23, HIGH);
    digitalWrite(24, LOW);
  }

  if (nbGesture >= 121) {
    digitalWrite(22, LOW);
    digitalWrite(23, LOW);
    digitalWrite(24, LOW);
    delay(1000000);
  }

  // wait for significant motion
  while (samplesRead == numSamples) {
    if (IMU.gyroscopeAvailable()) {
      // read the acceleration data
      IMU.readGyroscope(gX, gY, gZ);

      // sum up the absolutes
      float gSum = fabs(gX) + fabs(gY) + fabs(gZ);

      // check if it's above the threshold
      if (gSum >= gyroscopeThreshold) {
        // reset the sample read count
        samplesRead = 0;
        break;
      }
    }
  }

  // check if the all the required samples have been read since
  // the last time the significant motion was detected
  while (samplesRead < numSamples) {
    // check if both new acceleration and gyroscope data is
    // available
    if (IMU.accelerationAvailable() && IMU.gyroscopeAvailable()) {
      // read the acceleration and gyroscope data
      IMU.readAcceleration(aX, aY, aZ);
      IMU.readGyroscope(gX, gY, gZ);

      samplesRead++;

      // print the data in CSV format
      Serial.print(aX, 3);
      Serial.print(',');
      Serial.print(aY, 3);
      Serial.print(',');
      Serial.print(aZ, 3);
      Serial.print(',');
      Serial.print(gX, 3);
      Serial.print(',');
      Serial.print(gY, 3);
      Serial.print(',');
      Serial.print(gZ, 3);
      Serial.println();

      if (samplesRead == numSamples) {
        // add an empty line if it's the last sample
        Serial.println();
        nbGesture++;
        digitalWrite(22, LOW);
        digitalWrite(23, LOW);
        digitalWrite(24, LOW);
        delay(500);
        digitalWrite(22, HIGH);
        digitalWrite(23, HIGH);
        digitalWrite(24, HIGH);
        delay(500);
      }
    }
  }
}
